body {
  padding-top: 60px;
}
@media (max-width: 979px) {
  body {
    padding-top: 0px;
  }
}
#container {
    width: 960px;
    margin: 50 auto;
}

#contentcolumn {
    max-width: 760px;
}
#q {
    width: 150px;
}

img {
    max-width: 90%;
}

.postbox {
    border-bottom: 2px solid darkgrey;
    margin-bottom: 12px;
}

.footerbox {padding: 15px; text-align: center; margin-bottom: 15px;}

td.label {
    /* Issue #290 */
    background-color: inherit;
}

.footnote-reference {
    /* Issue 290 */
    vertical-align: super;
    font-size: xx-small;
}

.caption {
    /* Issue 292 */
    text-align: center;
    padding-top: 1em;
}

div.figure > img,
div.figure > a > img {
    /* Issue 292 */
    display: block;
    margin-left: auto;
    margin-right: auto;
}

div.sidebar, div.admonition, div.attention, div.caution, div.danger, div.error, div.hint, div.important, div.note, div.tip, div.warning {
    /* Issue 277 */
    border: 1px solid #aaa;
    border-radius: 5px;
}

blockquote p, blockquote {
  font-size: 17.5px;
  font-weight: 300;
  line-height: 1.25;
}

ul.bricks > li {
    display: inline;
    background-color: lightblue;
    padding: 8px;
    border-radius: 5px;
    line-height: 3;
    white-space:nowrap;
    margin: 3px;
}

ul.breadcrumb > li:before {
    content: " / ";
}

pre, pre code {
    white-space: pre;
    word-wrap: normal;
    overflow: auto;
}

article.post-micro {
    font-family: Georgia, 'Times New Roman', Times, serif;
    font-size: 1.5em;
}

/* fix anchors for headers */
h1, h2, h3 {
    margin-top: -40px;
    padding-top: 60px;
}

h4, h5, h6 {
    margin-top: -50px;
    padding-top: 60px;
}

h1.panel-title, h2.panel-title, h3.panel-title, h4.panel-title, h5.panel-title, h6.panel-title {
    margin-top: 0;
    margin-bottom: 0;
    padding-top: 0;
}

.image-block {
    display: inline-block;
}

.flowr_row {
    width: 100%;
}

.tags {
    padding-left: 0;
    margin-left: -5px;
    list-style: none;
    text-align: center;

}

.tags > li {
    display: inline-block;
    min-width: 10px;
    padding: 3px 7px;
    font-size: 12px;
    font-weight: bold;
    line-height: 1;
    color: #fff;
    text-align: center;
    white-space: nowrap;
    vertical-align: baseline;
    background-color: #999;
    border-radius: 10px;
}

.tags > li a {
    color: #fff;
}

.metadata p:before,
.postlist .listdate:before {
    content: " — ";
}

.metadata p:first-of-type:before {
    content: "";
}

.metadata p {
    display: inline;
}

.posttranslations h3 {
    display: inline;
    font-size: 1em;
    font-weight: bold;
}

.posttranslations h3:last-child {
    display: none;
}

.entry-content {
    margin-top: 1em;
}

.navbar .brand {
    padding: 0 20px;
}

.navbar .brand #blog-title {
    padding: 10px 0;
    display: inline-block;
}

.sr-only {
    position: absolute;
    width: 1px;
    height: 1px;
    padding: 0;
    margin: -1px;
    overflow: hidden;
    clip: rect(0, 0, 0, 0);
    border: 0;
}

.sr-only-focusable:active,
.sr-only-focusable:focus {
    position: static;
    width: auto;
    height: auto;
    margin: 0;
    overflow: visible;
    clip: auto;
}
