# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "",
    "Also available in:": "",
    "Archive": "",
    "Categories": "الأصناف",
    "Comments": "التّعليقات",
    "LANGUAGE": "العربيّة",
    "Languages:": "",
    "More posts about %s": "المزيد من المقالات حول %s",
    "Newer posts": "",
    "Next post": "",
    "No posts found.": "",
    "Nothing found.": "",
    "Older posts": "",
    "Original site": "",
    "Posted:": "",
    "Posts about %s": "",
    "Posts for year %s": "",
    "Posts for {month} {year}": "",
    "Previous post": "",
    "Publication date": "",
    "RSS feed": "",
    "Read in English": "",
    "Read more": "قراءة المزيد",
    "Skip to main content": "",
    "Source": "",
    "Tags and Categories": "",
    "Tags": "",
    "old posts, page %d": "",
    "page %d": "",
}
